use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
App
AppOpts
Astrophysical
CacheID
Diab
Env
Example
FTOOLS
HEADAS
Jerius
Null
Observatory
Smithsonian
SysFatal
appexec
cacheid
djerius
dmlist
env
envs
fhelp
lib
qexec
sandboxing
script
str
uncache
